@@ -331,10 +331,7 @@ gupnp_context_dispose (GObject *object)
         context = GUPNP_CONTEXT (object);
         priv = gupnp_context_get_instance_private (context);
 
-        if (priv->session) {
-                g_object_unref (priv->session);
-                priv->session = NULL;
-        }
+        g_clear_object (&priv->session);
 
         while (priv->host_path_datas) {
                 HostPathData *data;
@@ -344,10 +341,7 @@ gupnp_context_dispose (GObject *object)
                 gupnp_context_unhost_path (context, data->server_path);
         }
 
-        if (priv->server) {
-                g_object_unref (priv->server);
-                priv->server = NULL;
-        }
+        g_clear_object (&priv->server);
 
         /* Call super */
         object_class = G_OBJECT_CLASS (gupnp_context_parent_class);
@@ -1715,3 +1709,71 @@ out:
 
         return retval;
 }
+
+gboolean
+validate_host_header (const char *host_header,
+                      const char *host_ip,
+                      guint context_port)
+{
+
+        gboolean retval = FALSE;
+        // Be lazy and let GUri do the heavy lifting here, such as stripping the
+        // [] from v6 addresses, splitting of the port etc.
+        char *uri_from_host = g_strconcat ("http://", host_header, NULL);
+
+        char *host = NULL;
+        int port = 0;
+        GError *error = NULL;
+
+        g_uri_split_network (uri_from_host,
+                             G_URI_FLAGS_NONE,
+                             NULL,
+                             &host,
+                             &port,
+                             &error);
+
+        if (error != NULL) {
+                g_debug ("Failed to parse HOST header from request: %s",
+                         error->message);
+                goto out;
+        }
+
+        // -1 means there was no :port; according to UDA this is allowed and
+        // defaults to 80, the HTTP port then
+        if (port == -1) {
+                port = 80;
+        }
+
+        if (!g_str_equal (host, host_ip)) {
+                g_debug ("Mismatch between host header and host IP (%s, "
+                         "expected: %s)",
+                         host,
+                         host_ip);
+        }
+
+        if (port != context_port) {
+                g_debug ("Mismatch between host header and host port (%d, "
+                         "expected %d)",
+                         port,
+                         context_port);
+        }
+
+        retval = g_str_equal (host, host_ip) && port == context_port;
+
+out:
+        g_clear_error (&error);
+        g_free (host);
+        g_free (uri_from_host);
+
+        return retval;
+}
+
+gboolean
+gupnp_context_validate_host_header (GUPnPContext *context,
+                                    const char *host_header)
+{
+        return validate_host_header (
+                host_header,
+                gssdp_client_get_host_ip (GSSDP_CLIENT (context)),
+                gupnp_context_get_port (context));
+}
